@@ -10,6 +10,7 @@ from click import ClickException
 from . import __version__
 from .build_html import HTMLBuilder
 from .core import Core
+from .setup import setup_github_action
 
 from .pandoc import print_pandoc_info
 
@@ -160,3 +161,28 @@ def build(
 def info():
     core = Core()
     core.info()
+
+
+@supermark.command(help="Setup a project.")
+@click.option(
+    "-g",
+    "--githubaction",
+    "githubaction",
+    is_flag=True,
+    default=False,
+    help="Add a Github action so that projects are built after each commit.",
+)
+@click.option(
+    "-p",
+    "--path",
+    "path",
+    type=click.Path(exists=True, readable=True, path_type=Path),
+    help="Base path containing the source files. Current working directory is default.",
+)
+def setup(
+    githubaction: bool = False,
+    path: Optional[Path] = None,
+):
+    base_path = path or Path.cwd()
+    if githubaction:
+        setup_github_action(base_path)
