@@ -217,7 +217,7 @@ class Core:
 
     def get_css(self, used_extensions: Set[Extension]) -> str:
         all_css: str = ""
-        for extension in used_extensions:
+        for extension in sorted(list(used_extensions), key=lambda e: e.folder):
             all_css += extension.get_css() + "\n"
         return all_css
 
